@@ -11,7 +11,7 @@ except ImportError:
     except Exception:
         click.secho(
             "Found no way to get the current version. Falling back to 0.0.0.",
-            fg="red",
+            fg="yellow",
             err=True,
         )
         __version__ = "0.0.0"
