@@ -13,7 +13,7 @@ def test_upload_db_for_restore_no_db_service(
     db_upload_request = api_requests.UploadDBRequest(base_session)
     db_upload_request.get_login = MagicMock(return_value=False)
 
-    expected_err = fr"{messages.BAD_REQUEST}[\s|\S]*{response_text}"
+    expected_err = rf"{messages.BAD_REQUEST}[\s|\S]*{response_text}"
     with pytest.raises(
         api_requests.APIRequestError,
         match=expected_err,
