@@ -17,7 +17,9 @@ def get_license(path):
 def load_config(fname, path=None):
     config_fpath = os.path.join(path or ".", fname)
     if not os.path.exists(config_fpath):
-        raise exceptions.DivioException(messages.FILE_NOT_FOUND.format(config_fpath))
+        raise exceptions.DivioException(
+            messages.FILE_NOT_FOUND.format(config_fpath)
+        )
 
     with open(config_fpath) as f:
         try:
@@ -40,6 +42,8 @@ def validate_package_config(config, required_keys, path):
 
     for key in required_keys:
         if key not in config:
-            errors.append('Required key "{}" not found in config file.'.format(key))
+            errors.append(
+                'Required key "{}" not found in config file.'.format(key)
+            )
 
     return errors
